HISTORY
-------


0.4.1 (2015-04-26)
^^^^^^^^^^^^^^^^^^

* Fixes pep8 violations.
* Fixes pep257 violations.

0.4.0 (2014-07-25)
^^^^^^^^^^^^^^^^^^

* Applied pychecker and pylint, and fixed those violations.
* Increase code coverage to > 90%.

0.3 (2013-12-23)
^^^^^^^^^^^^^^^^

* Change template layout
* Change "--template-path" option to be requrired
* Fix a bug: always used a default template instead of a loaded template

  * Thanks to Kojima Takanori <takanori.kojima@gmail.com> for patch.


0.2 (2012-09-21)
^^^^^^^^^^^^^^^^

* suport pystache 0.5.x
* Refacotroing

0.1 (2011-12-01)
^^^^^^^^^^^^^^^^

* First release

